package cc2_medicaments;

import java.util.*;

public class Ordonnance {
	
	private final String nomMedecin, nomPatient; // final car invariables
	private ArrayList<Medicament> listeMedi = new ArrayList<>();

	public Ordonnance(String nM, String nP)
	{this.nomMedecin=nM; this.nomPatient =nP;}
	
	public String getNomMedecin() {
		return nomMedecin;
	}

	public String getNomPatient() {
		return nomPatient;
	}

	// on ne peut écrire d'accesseur en écriture (de type 'set') pour
	// nomMedecin et nomPatient
	
	// on ne doit pas écrire d'accesseur en écriture pour listeMedi
	// et l'ajout d'élément doit passer par une méthode spécialisée
	// on n'offre donc un accesseur en lecture (de type 'get')
	// qu'avec une vue non modifiable
	
	public ArrayList<Medicament> getListeMedi() {
		return (ArrayList<Medicament>)Collections.unmodifiableList(listeMedi);
	}
	
	// retourne le premier médicament de l'ordonnance rencontré 
	// qui a pour nom de molécule principale 
	// le nom de molécule passé en paramètre, et null s'il n'en existe pas
	
	public Medicament medicDeNom(String nom) {
		for (Medicament m: this.listeMedi) {
			if (m.getNomMolecule().equals(nom)) {
				return m;
			}
		}
		return null;
	}
	
	// ajoute un médicament à l'ordonnance s'il n'y a pas déjà 
	// un médicament qui a la même molécule principale
	// affiche un message si l'ajout n'a pas pu avoir lieu
	
	public void ajoute(Medicament m) {
		if (this.medicDeNom(m.getNomMolecule())!=null)
		{
			System.out.println("l'ordonnance contient déjà un "
					+ "médicament de nom de molécule principale "+m.getNomMolecule());
		}
		else 
		{
			this.listeMedi.add(m);
		}
	}
	
	// retourne les médicaments de l'ordonnance dont la durée de conservation 
	// est passée en paramètre

	public ArrayList<Medicament> medicDeDuree(int d) {
		ArrayList<Medicament> resultat = new ArrayList<> ();
		for (Medicament m: this.listeMedi) {
			if (m.getDureeConservation()==d) {
				resultat.add(m);
			}
		}
		return resultat;
	}
	
	@Override
	public String toString() {
		return "Ordonnance [nomMedecin=" + nomMedecin + ", nomPatient=" + 
				nomPatient + ", \nlisteMedi=" + listeMedi + "]";
	}

	public static void main(String[] argv) {
		Medicament m1 = new Medicament("Paracétamol", 65, 24);
		Medicament m2 = new Medicament("Paracétamol", 100, 30);
		Medicament m3 = new Medicament("Vitamine D", 100, 12);
		Medicament m4 = new Medicament("Vitamine C", 100, 24);		

		Ordonnance o1 = new Ordonnance("Dr Marie","Patient Thibault");
		o1.ajoute(m1);
		o1.ajoute(m2);	
		o1.ajoute(m3);	
		o1.ajoute(m4);	
		System.out.println(o1);		
		System.out.println(o1.medicDeDuree(24));	
		System.out.println(o1.medicDeNom("Vitamine D"));				
	}

}
